package com.logicbig.example;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.EntityTag;
import javax.ws.rs.core.Request;
import javax.ws.rs.core.Response;
import java.util.Date;

@Path("/users")
public class UserResource {

    @GET
    public Response getUsers(@Context Request request) {
        Date lastModifiedDate = UserService.Instance.getUsersLastModifiedDate();
        Response.ResponseBuilder responseBuilder = request.evaluatePreconditions(lastModifiedDate);
        if (responseBuilder == null) {//last modified date didn't match, send new content
            return Response.ok("dummy user list")
                           .lastModified(lastModifiedDate)
                           .build();
        } else {
            //sending 304 not modified
            return responseBuilder.build();
        }
    }

    @GET
    @Path("{id}")
    public Response getUser(@PathParam("id") String id, @Context Request request) {
        EntityTag eTag = UserService.Instance.getETagForUser(id);
        Response.ResponseBuilder responseBuilder = request.evaluatePreconditions(eTag);
        if (responseBuilder == null) {//eTag has changed, sending new content
            return Response.ok(UserService.Instance.getUser(id))
                           .tag(eTag)
                           .build();
        } else {
            //sending 304 not modified
            return responseBuilder.build();
        }
    }
}